@@ -51,17 +51,15 @@ class Tredis_publish(threading.Thread):
         while True:
             try:
                 channel, message = self.queue_publish.get(timeout=1)
-            except queue.Empty:
-                pass
-            else:
-                logger.info(f'real publish: {channel} {message}')
                 self.r.publish(channel, message)
                 self.queue_publish.task_done()
                 if channel == Tredis_publish.str_exit_magic_words and message == Tredis_publish.str_exit_magic_words:
                     break
+            except queue.Empty:
+                pass
 
     def publish(self, channel, message):
-        logger.info(f'queue publish: {channel} {message}')
+        # logger.info(f'queue publish: {channel} {message}')
         self.queue_publish.put((channel, message), block=True)
 
     def stop(self):
