@@ -1,6 +1,7 @@
 import xlrd
 import pandas as pd
 from collections import defaultdict
+import datetime
 
 
 #
@@ -51,7 +52,13 @@ def read_warrant_bible(path_file='權證達人寶典_NEWVOL_2022-07-15.xls') ->
 
     dict_stock_to_warrant = defaultdict(list)
 
+    date_today = datetime.datetime.today()
+
     for x in dict_warrant_to_info:
+        date_due = datetime.datetime.strptime(dict_warrant_to_info[x]['到期日期'], '%Y/%m/%d')
+        days_number_due = (date_due - date_today).days
+        dict_warrant_to_info[x]['到期天數'] = days_number_due
+        dict_warrant_to_info[x]['Volume'] = 0
         code = dict_warrant_to_info[x]['標的代碼']
         dict_stock_to_warrant[code].append(x)
 
